@@ -17,6 +17,8 @@ from .rpc import RPC_PORTS, autodetect_cli_confs, get_default_datadir, RpcError
 from .rpc_cache import BitcoinCLICached
 from .serializations import PSBT
 
+logger = logging.getLogger(__name__)
+
 # a gap of 20 addresses is what many wallets do
 WALLET_CHUNK = 20
 # we don't need to scan earlier than that 
@@ -135,7 +137,7 @@ class Specter:
                 self._info = self.cli.getblockchaininfo()
                 self._is_running = True
             except Exception as e:
-                logging.error("Exception %s while specter.check()" % e)
+                logger.error("Exception %s while specter.check()" % e)
                 pass
 
         if not self._is_running:
@@ -162,7 +164,7 @@ class Specter:
         try:
             self.wallets.load_all()
         except Exception as e:
-            logging.error("can't load wallets: %s " % e)
+            logger.error("can't load wallets: %s " % e)
 
     def test_rpc(self, **kwargs):
         conf = copy.deepcopy(self.config["rpc"])
@@ -180,7 +182,7 @@ class Specter:
                 cli.listwallets()
                 r['tests']['wallets'] = True
             except RpcError as rpce:
-                logging.error(rpce)
+                logger.error(rpce)
                 if rpce.status_code ==  404:
                     r['tests']['wallets'] = False
                 else:
@@ -189,18 +191,18 @@ class Specter:
             r["err"] = ""
             r["code"] = 0
         except ConnectionError as e:
-            logging.error(e)
+            logger.error(e)
             r['tests']['connectable'] = False
             r["err"] = "Failed to connect!"
             r["code"] = -1
         except RpcError as rpce:
-            logging.error(rpce)
+            logger.error(rpce)
             if rpce.status_code ==  401:
                 r['tests']['credentials'] = False
             else:
                 raise rpce
         except Exception as e:
-            logging.error(e)
+            logger.error(e)
             r["out"] = ""
             if cli.r is not None and "error" in cli.r:
                 r["err"] = cli.r["error"]
@@ -319,7 +321,7 @@ class DeviceManager:
         for dev in self:
             if dev["alias"] == fname:
                 return dev
-        logging.error("Could not find Device %s" % fname)
+        logger.error("Could not find Device %s" % fname)
 
     def remove(self, device):
         os.remove(device["fullpath"])
@@ -410,7 +412,7 @@ class WalletManager:
                 if os.path.join(self.cli_path,wallets[k]["alias"]) in existing_wallets:
                     self._wallets[k] = wallets[k]
                 else:
-                    logging.warn("Couldn't find wallet %s in core's wallets. Silently ignored!" % wallets[k]["alias"])
+                    logger.warn("Couldn't find wallet %s in core's wallets. Silently ignored!" % wallets[k]["alias"])
         else:
             self._wallets = {}
 
@@ -419,14 +421,14 @@ class WalletManager:
         loadable_wallets = [w["name"] for w in self.cli.listwalletdir()["wallets"]]
         not_loaded_wallets = [w for w in loadable_wallets if w not in loaded_wallets]
         if not_loaded_wallets != []:
-            logging.warn("not loaded wallets:%s" % not_loaded_wallets)
+            logger.warn("not loaded wallets:%s" % not_loaded_wallets)
         for k in self._wallets:
             if os.path.join(self.cli_path,self._wallets[k]["alias"]) in not_loaded_wallets:
-                logging.debug("loading %s " % self._wallets[k]["alias"])
+                logger.debug("loading %s " % self._wallets[k]["alias"])
                 self.cli.loadwallet(os.path.join(self.cli_path,self._wallets[k]["alias"]))
                 if "pending_psbts" in self._wallets[k] and len(self._wallets[k]["pending_psbts"]) > 0:
                     for psbt in self._wallets[k]["pending_psbts"]:
-                        logging.debug("lock %s " % self._wallets[k]["alias"], self._wallets[k]["pending_psbts"][psbt]["tx"]["vin"])
+                        logger.debug("lock %s " % self._wallets[k]["alias"], self._wallets[k]["pending_psbts"][psbt]["tx"]["vin"])
                         Wallet(self._wallets[k], self).cli.lockunspent(False, [utxo for utxo in self._wallets[k]["pending_psbts"][psbt]["tx"]["vin"]])
 
     def get_by_alias(self, alias):
@@ -545,7 +547,7 @@ class WalletManager:
         return w
 
     def delete_wallet(self, wallet):
-        logging.info("Deleting {}".format(wallet["alias"]))
+        logger.info("Deleting {}".format(wallet["alias"]))
         self.cli.unloadwallet(os.path.join(self.cli_path,wallet["alias"]))
         # Try deleting wallet file
         if get_default_datadir() and os.path.exists(os.path.join(get_default_datadir(), os.path.join(self.cli_path,wallet["alias"]))):
@@ -555,7 +557,7 @@ class WalletManager:
             os.remove(wallet["fullpath"])
 
     def rename_wallet(self, wallet, name):
-        logging.info("Renaming {}".format(wallet["alias"]))
+        logger.info("Renaming {}".format(wallet["alias"]))
         wallet["name"] = name
         if self.working_folder is not None:
             with open(wallet["fullpath"], "w+") as f:
@@ -1001,7 +1003,7 @@ class Wallet(dict):
         """
         if self.fullbalance < amount:
             return None
-        logging.debug("fee unit: %s" % fee_unit)
+        logger.debug("fee unit: %s" % fee_unit)
         if fee_unit not in ["SAT_B", "BTC_KB"]:
             raise ValueError('Invalid bitcoin unit')
 
@@ -1087,7 +1089,7 @@ class Wallet(dict):
                 inp.unknown[b"\xfc\xca\x01"+self.fingerprint] = b"".join([i.to_bytes(4, "little") for i in inp.hd_keypaths[k][-2:]])
                 inp.hd_keypaths = {}
         psbt["specter"]=qr_psbt.serialize()
-        logging.info("PSBT for Specter: %s" % psbt["specter"])
+        logger.info("PSBT for Specter: %s" % psbt["specter"])
 
         self.cli.lockunspent(False, psbt["tx"]["vin"])
 
