@@ -1,6 +1,9 @@
+import logging
 import requests, json, os
 import os, sys, errno
 
+logger = logging.getLogger(__name__)
+
 # TODO: redefine __dir__ and help
 
 RPC_PORTS = { "test": 18332, "regtest": 18443, "main": 8332, 'signet': 38332 }
