@@ -11,6 +11,8 @@ from .descriptor import AddChecksum
 from .logic import Specter
 from .views.hwi import hwi_views
 
+logger = logging.getLogger(__name__)
+
 env_path = Path('.') / '.flaskenv'
 load_dotenv(env_path)
 
@@ -26,7 +28,7 @@ def create_app(config="cryptoadvance.specter.config.DevelopmentConfig"):
         # https://pyinstaller.readthedocs.io/en/v3.3.1/runtime-information.html#using-sys-executable-and-sys-argv-0
         template_folder = os.path.join(sys._MEIPASS, 'templates')
         static_folder = os.path.join(sys._MEIPASS, 'static')
-        logging.info("pyinstaller based instance running in {}".format(sys._MEIPASS))
+        logger.info("pyinstaller based instance running in {}".format(sys._MEIPASS))
         app = Flask(__name__, template_folder=template_folder, static_folder=static_folder)
     else:
         app = Flask(__name__, template_folder="templates", static_folder="static")
@@ -65,6 +67,13 @@ def init_app(app, specter=None):
     app.register_blueprint(hwi_views, url_prefix='/hwi')
     with app.app_context():
         from . import controller
+        if app.config.get("TESTING") and len(app.view_functions) <=9 :
+            # Need to force a reload as otherwise the import is skipped
+            # in pytest, the app is created anew for ech test
+            # But we shouldn't do that if not necessary as this would result in
+            # --> View function mapping is overwriting an existing endpoint function
+            import importlib
+            importlib.reload(controller)
     return app
 
 def create_and_init():
